using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
// Import namespaces for SqlClient and System.IO
using System.Data.SqlClient;
using System.IO;

public partial class _DeleteSql : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // This code will only be executed if the page load not is a post back.
        if (!Page.IsPostBack)
        {
            try
            {
                // Get the UserID.
                txtUserID.Text = Convert.ToString(Session["UserID"]);

                // Set page index to the last page.
                GridView1.PageIndex = Int32.MaxValue;
            }
            catch (Exception ex)
            {
                // Catch a general exception
                Response.Write(ex.Message);
            }
        }
    }

    protected void DeletOnePostButton_Click(object sender, EventArgs e)
    {
        // Delete one row in the Users table where the UserID is equal to the active user

        // Declare variables for a connection string and the DELETE statement
        string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "DELETE FROM Users WHERE UserID = @UserID";

        // Create a SqlConnection. The using block is used to call dispose (close) automatically even 
        // if there are an exception.
        using (SqlConnection cn = new SqlConnection(ConnString))
        {
            // Create a SqlCommand.
            SqlCommand cmd = new SqlCommand(sql, cn);

            // Add parameters for the WHERE clause.
            cmd.Parameters.AddWithValue("@UserID", txtUserID.Text);

            // The Try/Catch/Finally block is used to handle exceptions.
            try
            {
                // Open the connection
                cn.Open();

                // Execute the DELETE statement.
                cmd.ExecuteNonQuery();

            }
            catch (Exception ex)
            {
                Response.Write(ex.Message);
            }
            finally
            {
                // Dispose the SqlCommand
                cmd.Dispose();
            }
        }
    }
    protected void DeleteCarsButton_Click(object sender, EventArgs e)
    {
        // Delete cars in the Cars table where the Year is equal to the entered year in the textbox

        // Declare variables for a connection string and the DELETE statement
        string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
        string sql = "DELETE FROM Cars WHERE Year = @Year";

        // Create a SqlConnection. The using block is used to call dispose (close) automatically even 
        // if there are an exception.
        using (SqlConnection cn = new SqlConnection(ConnString))
        {
            // Create a SqlCommand.
            SqlCommand cmd = new SqlCommand(sql, cn);

            // Add parameters for the WHERE clause.
            cmd.Parameters.AddWithValue("@Year", txtCarYear.Text);

            // The Try/Catch/Finally block is used to handle exceptions.
            try
            {
                // Open the connection
                cn.Open();

                // Execute the DELETE statement.
                cmd.ExecuteNonQuery();

            }
            catch (Exception ex)
            {
                Response.Write(ex.Message);
            }
            finally
            {
                // Dispose the SqlCommand
                cmd.Dispose();
            }
        }
    }
    protected void GridView1_RowCommand(object sender, GridViewCommandEventArgs e)
    {
        if (e.CommandName == "Download")
        {
            string xbrlFilUrl = (e.CommandArgument).ToString();

            // Gives the user a save dialog to download the xbrlfile
            Response.Clear();
            Response.ContentType = "Application/xbrl";
            Response.AppendHeader("Content-Disposition", "attachment; filename=Revisionsberattelse.xbrl");
            Response.WriteFile(xbrlFilUrl);
            Response.Flush();
            Response.Close();
        }

        if (e.CommandName == "Delete")
        {
            // We get the URL of the RevisionFile from the CommandArgument but have to find out the FileID as well
            string RevisionFile = (e.CommandArgument).ToString();

            // Code to get the FileID from the GridView
            ImageButton lb = (ImageButton)e.CommandSource;
            GridViewRow gvRow = (GridViewRow)lb.BindingContainer;
            string FileID = gvRow.RowIndex.ToString();

            // Delete row in database and delete the xbrl-file that is saved on our webserver

            // Declare variables for connection string and the DELETE statement
            string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sql = "DELETE FROM Revision WHERE RevisionID = @RevisionID";

            // Create a SqlConnection. The using block is used to call dispose (close) automatically even if 
            // there are an exception.
            using (SqlConnection cn = new SqlConnection(ConnString))
            {
                // Create a SqlCommand.
                SqlCommand cmd = new SqlCommand(sql, cn);

                // Add parameters
                cmd.Parameters.AddWithValue("@RevisionID", FileID);

                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Execute the DELETE statement.
                    cmd.ExecuteNonQuery();

                    // Delete xbrl-file
                    FileInfo FileToDelete = new FileInfo(Server.MapPath(RevisionFile));
                    if (FileToDelete.Exists)
                    {
                        FileToDelete.Delete();
                    }
                }
                catch (Exception ex)
                {
                    // Catch a general exception.
                    Response.Write(ex.Message);
                }
                finally
                {
                    // Dispose the SqlCommand
                    cmd.Dispose();
                }
            }
        }
    }
}
